API
===    

.. autosummary::
    :toctree: api/

    fdtdx.apply_params
    fdtdx.ArrayContainer
    fdtdx.autoinit
    fdtdx.BinaryMedianFilterModule
    fdtdx.boundary_objects_from_config
    fdtdx.BoundaryConfig
    fdtdx.BrushConstraint2D
    fdtdx.circular_brush
    fdtdx.ClosestIndex
    fdtdx.colors.Color
    fdtdx.compute_energy
    fdtdx.compute_mode
    fdtdx.compute_poynting_flux
    fdtdx.ConnectHolesAndStructures
    fdtdx.Cylinder
    fdtdx.Detector
    fdtdx.Device
    fdtdx.DiagonalSymmetry2D
    fdtdx.DtypeConversion
    fdtdx.EnergyDetector
    fdtdx.export_arrays_snapshot_to_vti
    fdtdx.export_json
    fdtdx.export_json_str
    fdtdx.export_stl
    fdtdx.export_vti
    fdtdx.ExtrudedPolygon
    fdtdx.field
    fdtdx.FieldDetector
    fdtdx.frozen_field
    fdtdx.frozen_private_field
    fdtdx.full_backward
    fdtdx.GaussianPlaneSource
    fdtdx.GaussianPulseProfile
    fdtdx.GaussianSmoothing2D
    fdtdx.GradientConfig
    fdtdx.GridCoordinateConstraint
    fdtdx.import_from_json
    fdtdx.LinearReconstructEveryK
    fdtdx.Logger
    fdtdx.Material
    fdtdx.metric_efficiency
    fdtdx.ModeOverlapDetector
    fdtdx.ModePlaneSource
    fdtdx.normalize_by_energy
    fdtdx.normalize_by_poynting_flux
    fdtdx.ObjectContainer
    fdtdx.OnOffSwitch
    fdtdx.ParameterTransformation
    fdtdx.PerfectlyMatchedLayer
    fdtdx.PeriodicBoundary
    fdtdx.PhasorDetector
    fdtdx.PillarDiscretization
    fdtdx.place_objects
    fdtdx.plot_setup
    fdtdx.plot_setup_from_side
    fdtdx.plot_setup_from_side
    fdtdx.plot_material_from_side
    fdtdx.plot_material
    fdtdx.plot_field_slice_component
    fdtdx.plot_field_slice
    fdtdx.PositionConstraint
    fdtdx.PoyntingFluxDetector
    fdtdx.private_field
    fdtdx.RealCoordinateConstraint
    fdtdx.Recorder
    fdtdx.RecordingState
    fdtdx.RemoveFloatingMaterial
    fdtdx.run_fdtd
    fdtdx.resolve_object_constraints
    fdtdx.SimulationConfig
    fdtdx.SimulationObject
    fdtdx.SimulationState
    fdtdx.SimulationVolume
    fdtdx.SingleFrequencyProfile
    fdtdx.SizeConstraint
    fdtdx.SizeExtensionConstraint
    fdtdx.Sphere
    fdtdx.StandardToCustomRange
    fdtdx.StandardToInversePermittivityRange
    fdtdx.StandardToPlusOneMinusOneRange
    fdtdx.SubpixelSmoothedProjection
    fdtdx.TanhProjection
    fdtdx.TreeClass
    fdtdx.UniformMaterialObject
    fdtdx.UniformPlaneSource
    fdtdx.WaveCharacter
    fdtdx.wavelength_to_period
